@@ -4,15 +4,21 @@ context("ffStack NA handling")
 testdf1 <- data.frame(facNA.int=factor(c(letters[1:3],NA)),
                       intNA.fac=c(1,2,3,NA),
                       facNA.intNA=factor(c(letters[1:3],NA)),
-                      fac.NA=factor(1))
+                      fac.NA=factor(1),
+                      allNA=NA,
+                      emptystring=factor(c("",1:3)))
+
 testdf2 <- data.frame(facNA.int=2,
                       intNA.fac=factor(letters[1:4]),
                       facNA.intNA=c(1,2,3,NA),
-                      NA.fac=factor(2))
+                      NA.fac=factor(2),
+                      allNA=NA,
+                      emptystring=factor(c("",4:6)))
 ffdf1 <- ff::as.ffdf(.preparedf(testdf1))
 ffdf2 <- ff::as.ffdf(.preparedf(testdf2))
 stacked1 <- try(ffStack(ffdf2, testdf1))
 stacked2 <- try(ffStack(ffdf1, testdf2))
+stacked3 <- ffStack(ffdf1,ffdf2)
 test_that("Stack() handles mixed factor/integers with NAs", {
     expect_true(nrow(stacked1)>0)
     expect_true(nrow(stacked2)>0)
